@@ -13,7 +13,7 @@ do_view_action() {
 
     case "${filetype}" in
     iso9660)
-         if which isoinfo > /dev/null 2>&1; then
+         if command -v isoinfo >/dev/null 2>&1; then
              isoinfo -d -i "${MC_EXT_FILENAME}" && isoinfo -l -R -J -i "${MC_EXT_FILENAME}"
          else
              7za l "${MC_EXT_FILENAME}"
@@ -27,7 +27,7 @@ do_view_action() {
         ;;
     lib)
         gplib -t "${MC_EXT_FILENAME}" | \
-            /usr/pkg/bin/perl -e 'while (<>) { @a=split /[\s\t]+/, $_; printf ("%-30s | %10d | %s.%s.%02d | %s\n", $a[0], ($a[1]*1),$a[7], lc($a[4]), $a[5], $a[6]);}'
+            /usr/bin/perl -e 'while (<>) { @a=split /[\s\t]+/, $_; printf ("%-30s | %10d | %s.%s.%02d | %s\n", $a[0], ($a[1]*1),$a[7], lc($a[4]), $a[5], $a[6]);}'
         ;;
     so)
         file "${MC_EXT_FILENAME}" && nm -C -D "${MC_EXT_FILENAME}"
@@ -52,7 +52,7 @@ do_view_action() {
         lyxcat "${MC_EXT_FILENAME}"
         ;;
     torrent)
-        ctorrent -x "${MC_EXT_FILENAME}" 2>/dev/null
+        /usr/local/libexec/mc/extfs.d/torrent list "${MC_EXT_FILENAME}" 2>/dev/null
         ;;
     javaclass)
         jad -p "${MC_EXT_FILENAME}" 2>/dev/null || \
@@ -74,7 +74,7 @@ do_open_action() {
         sqlite3 "${MC_EXT_FILENAME}"
         ;;
     glade)
-        if which glade-3 >/dev/null 2>&1; then
+        if command -v glade-3 >/dev/null 2>&1; then
             (glade-3 "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
         else
             (glade-2 "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
